@@ -17,7 +17,7 @@ use Lemonldap::Config::Parameters;
 #}
 #### common declaration #######
 our (@ISA, $VERSION, @EXPORTS);
-$VERSION = '0.07';
+$VERSION = '0.10';
 our $VERSION_LEMONLDAP="1.1" ;
 our $VERSION_INTERNAL="0.03-4" ;
 
@@ -566,6 +566,13 @@ if ($tmpvar) {
 my @stack;
 @stack= grep ($id ne $_ ,@tmp);
 unshift @stack, $id;
+#### for avoid stack overflow 
+my %hashs;
+foreach (@stack) {
+$hashs{$_}=1;
+
+}
+
 my $config = \@stack;
 #my $configsx=Dumper ($config);
 #print STDERR "final = $configsx\n";
@@ -574,6 +581,13 @@ my $config = \@stack;
   print STDERR "sup  $to_delete\n";
   delete $STACK{$to_delete}; 
    }
+#### for avoid stack overflow 
+foreach (keys %STACK)  {
+next if /QUEUE/ ;
+delete $STACK{$_} unless $hashs{$_} ;
+ }
+
+
 #$Data::Dumper::Purity=1;
 #$Data::Dumper::Terse=1;
 my $buffer;
